==> microsoft-graph-beta-6.37.0-sources.jar: com/microsoft/graph/beta/models/windowsupdates/SoftwareUpdateFilter.java <==
package com.microsoft.graph.beta.models.windowsupdates;

import com.microsoft.kiota.serialization.Parsable;
import com.microsoft.kiota.serialization.ParseNode;
import com.microsoft.kiota.serialization.SerializationWriter;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
@jakarta.annotation.Generated("com.microsoft.kiota")
public class SoftwareUpdateFilter extends ContentFilter implements Parsable {
    /**
     * Instantiates a new {@link SoftwareUpdateFilter} and sets the default values.
     */
    public SoftwareUpdateFilter() {
        super();
        this.setOdataType("#microsoft.graph.windowsUpdates.softwareUpdateFilter");
    }
    /**
     * Creates a new instance of the appropriate class based on discriminator value
     * @param parseNode The parse node to use to read the discriminator value and create the object
     * @return a {@link SoftwareUpdateFilter}
     */
    @jakarta.annotation.Nonnull
    public static SoftwareUpdateFilter createFromDiscriminatorValue(@jakarta.annotation.Nonnull final ParseNode parseNode) {
        Objects.requireNonNull(parseNode);
        final ParseNode mappingValueNode = parseNode.getChildNode("@odata.type");
        if (mappingValueNode != null) {
            final String mappingValue = mappingValueNode.getStringValue();
            switch (mappingValue) {
                case "#microsoft.graph.windowsUpdates.driverUpdateFilter": return new DriverUpdateFilter();
                case "#microsoft.graph.windowsUpdates.qualityUpdateFilter": return new QualityUpdateFilter();
                case "#microsoft.graph.windowsUpdates.windowsUpdateFilter": return new WindowsUpdateFilter();
            }
        }
        return new SoftwareUpdateFilter();
    }
    /**
     * The deserialization information for the current model
     * @return a {@link Map<String, java.util.function.Consumer<ParseNode>>}
     */
    @jakarta.annotation.Nonnull
    public Map<String, java.util.function.Consumer<ParseNode>> getFieldDeserializers() {
        final HashMap<String, java.util.function.Consumer<ParseNode>> deserializerMap = new HashMap<String, java.util.function.Consumer<ParseNode>>(super.getFieldDeserializers());
        return deserializerMap;
    }
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    public void serialize(@jakarta.annotation.Nonnull final SerializationWriter writer) {
        Objects.requireNonNull(writer);
        super.serialize(writer);
    }
}

==> microsoft-graph-beta-6.47.0-sources.jar: com/microsoft/graph/beta/models/windowsupdates/SoftwareUpdateFilter.java <==
package com.microsoft.graph.beta.models.windowsupdates;

import com.microsoft.kiota.serialization.Parsable;
import com.microsoft.kiota.serialization.ParseNode;
import com.microsoft.kiota.serialization.SerializationWriter;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
@jakarta.annotation.Generated("com.microsoft.kiota")
public class SoftwareUpdateFilter extends ContentFilter implements Parsable {
    /**
     * Instantiates a new {@link SoftwareUpdateFilter} and sets the default values.
     */
    public SoftwareUpdateFilter() {
        super();
        this.setOdataType("#microsoft.graph.windowsUpdates.softwareUpdateFilter");
    }
    /**
     * Creates a new instance of the appropriate class based on discriminator value
     * @param parseNode The parse node to use to read the discriminator value and create the object
     * @return a {@link SoftwareUpdateFilter}
     */
    @jakarta.annotation.Nonnull
    public static SoftwareUpdateFilter createFromDiscriminatorValue(@jakarta.annotation.Nonnull final ParseNode parseNode) {
        Objects.requireNonNull(parseNode);
        final ParseNode mappingValueNode = parseNode.getChildNode("@odata.type");
        if (mappingValueNode != null) {
            final String mappingValue = mappingValueNode.getStringValue();
            switch (mappingValue) {
                case "#microsoft.graph.windowsUpdates.driverUpdateFilter": return new DriverUpdateFilter();
                case "#microsoft.graph.windowsUpdates.qualityUpdateFilter": return new QualityUpdateFilter();
                case "#microsoft.graph.windowsUpdates.remediationUpdateFilter": return new RemediationUpdateFilter();
                case "#microsoft.graph.windowsUpdates.windowsUpdateFilter": return new WindowsUpdateFilter();
            }
        }
        return new SoftwareUpdateFilter();
    }
    /**
     * The deserialization information for the current model
     * @return a {@link Map<String, java.util.function.Consumer<ParseNode>>}
     */
    @jakarta.annotation.Nonnull
    public Map<String, java.util.function.Consumer<ParseNode>> getFieldDeserializers() {
        final HashMap<String, java.util.function.Consumer<ParseNode>> deserializerMap = new HashMap<String, java.util.function.Consumer<ParseNode>>(super.getFieldDeserializers());
        return deserializerMap;
    }
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    public void serialize(@jakarta.annotation.Nonnull final SerializationWriter writer) {
        Objects.requireNonNull(writer);
        super.serialize(writer);
    }
}
